@@ -31,21 +31,19 @@
 #include	"Service.h"
 #include	"EventLog.h"
 
-#include	"Resource.h"
+#include	"resource.h"
 
 #include	"mDNSEmbeddedAPI.h"
 #include	"uDNS.h"
 #include	"mDNSWin32.h"
 #include	"mDNSDebug.h"
 
-#ifndef __MINGW32__
 #include	"Firewall.h"
-#endif
 
 #if( !TARGET_OS_WINDOWS_CE )
 	#include	<mswsock.h>
 	#include	<process.h>
-	#include	<ipExport.h>
+	#include	<ipexport.h>
 	#include	<ws2def.h>
 	#include	<ws2ipdef.h>
 	#include	<iphlpapi.h>
@@ -667,10 +665,8 @@ static OSStatus CheckFirewall()
 		err = translate_errno( size > 0, (OSStatus) GetLastError(), kPathErr );
 		require_noerr( err, exit );
 
-#ifndef __MINGW32__
 		err = mDNSAddToFirewall(fullPath, kServiceFirewallName);
 		require_noerr( err, exit );
-#endif
 
 		value = 1;
 		err = RegSetValueEx( key, kServiceManageFirewall, 0, REG_DWORD, (const LPBYTE) &value, sizeof( DWORD ) );
@@ -790,7 +786,7 @@ static void	ReportStatus( int inType, const char *inFormat, ... )
 			BOOL				ok;
 			const char *		array[ 1 ];
 			
-			vsprintf( s, inFormat, args );
+			vsnprintf( s, sizeof( s ), inFormat, args );
 			array[ 0 ] = s;
 			ok = ReportEventA( gServiceEventSource, (WORD) inType, 0, MDNSRESPONDER_LOG, NULL, 1, 0, array, NULL );
 			check_translated_errno( ok, GetLastError(), kUnknownErr );
